%bcond_without snmp
%bcond_without vrrp
%bcond_with profile
%bcond_with debug

%if 0%{?rhel} == 7
%global with_systemd 1
%else
%global with_systemd 0
%endif

Name: keepalived
Summary: Load balancer and high availability service
Version: 1.2.23
Release: 1%{?dist}
License: GPLv2+
URL: http://www.keepalived.org/
Group: System Environment/Daemons

Source0: http://www.keepalived.org/software/keepalived-%{version}.tar.gz
Source1: keepalived.init
Source2: keepalived.service

#Patch0: bz1100028-keepalived-man-snmp.patch

%if %{with_systemd}
BuildRequires: systemd-units
Requires: systemd-units
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
# This is actually needed for the %%triggerun script but Requires(triggerun)
# is not valid.  We can use %%post because this particular %%triggerun script
# should fire just after this package is installed.
Requires(post): systemd-sysv
%else
# This is for /sbin/service
Requires(preun): initscripts
Requires(postun): initscripts
%endif

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%if %{with snmp}
BuildRequires: net-snmp-devel
%endif
BuildRequires: openssl-devel
BuildRequires: libnl-devel
BuildRequires: kernel-devel
BuildRequires: popt-devel
BuildRequires: libnfnetlink-devel

%description
Keepalived provides simple and robust facilities for load balancing
and high availability.  The load balancing framework relies on the
well-known and widely used Linux Virtual Server (IPVS) kernel module
providing layer-4 (transport layer) load balancing.  Keepalived
implements a set of checkers to dynamically and adaptively maintain
and manage a load balanced server pool according their health.
Keepalived also implements the Virtual Router Redundancy Protocol
(VRRPv2) to achieve high availability with director failover.

%prep
%setup -q
#%patch0 -p1

%build
%configure \
    %{?with_debug:--enable-debug} \
    %{?with_profile:--enable-profile} \
    %{!?with_vrrp:--disable-vrrp} \
    %{?with_snmp:--enable-snmp}
%{__make} %{?_smp_mflags} STRIP=/bin/true

%install
%{__rm} -rf %{buildroot}
%{__rm} -rf doc/samples/*.pem
%{__make} install DESTDIR=%{buildroot}
%{__rm} -rf %{buildroot}%{_sysconfdir}/keepalived/samples/

# hier noch
%if %{with_systemd}
%{__install} -p -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/keepalived.service
%{__rm} -rf %{buildroot}%{_initrddir}/
%else
%{__install} -p -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%if %{with snmp}
%{__mkdir_p} -p %{buildroot}%{_datadir}/snmp/mibs/
%{__install} -p -m 0644 doc/KEEPALIVED-MIB %{buildroot}%{_datadir}/snmp/mibs/KEEPALIVED-MIB.txt
%{__install} -p -m 0644 doc/VRRP-MIB %{buildroot}%{_datadir}/snmp/mibs/VRRP-MIB.txt
rm -rf %{buildroot}%{_datadir}/snmp/mibs/VRRP-MIB %{buildroot}%{_datadir}/snmp/mibs/KEEPALIVED-MIB
%endif


%clean
%{__rm} -rf %{buildroot}


%post
%if 0%{?systemd_post:1}
%systemd_post keepalived.service
%else
if [ $1 = 1 ]; then
    # Initial installation
%if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%else
    /sbin/chkconfig --add keepalived

%endif
fi
%endif



%preun
%if 0%{?systemd_preun:1}
%systemd_preun keepalived.service
%else
if [ $1 = 0 ]; then
    # Package removal, not upgrade
%if %{with_systemd}
    /bin/systemctl --no-reload disable keepalived.service >/dev/null 2>&1 || :
    /bin/systemctl stop keepalived.service >/dev/null 2>&1 || :
%else
    /sbin/service keepalived stop >/dev/null 2>&1
    /sbin/chkconfig --del keepalived
%endif
fi
%endif

%postun
%if 0%{?systemd_postun_with_restart:1}
%systemd_postun_with_restart keepalived.service
%else
%if %{with_systemd}
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ]; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart keepalived.service >/dev/null 2>&1 || :
fi
%else
if [ $1 -ge 1 ]; then
    /sbin/service keepalived condrestart >/dev/null 2>&1 || :
fi
%endif
%endif


%files
%defattr(-,root,root,-)
%doc AUTHOR ChangeLog CONTRIBUTORS COPYING README TODO VERSION
%doc doc/keepalived.conf.SYNOPSIS doc/NOTE_vrrp_vmac.txt doc/samples/
%dir %{_sysconfdir}/keepalived/
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/keepalived/keepalived.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/keepalived

%if %{with_systemd}
%{_unitdir}/keepalived.service
%else
%{_sysconfdir}/rc.d/init.d/keepalived
%endif

%if %{with snmp}
%{_datadir}/snmp/mibs/KEEPALIVED-MIB.txt
%{_datadir}/snmp/mibs/VRRP-MIB.txt
%endif
%attr(0755,root,root) %{_bindir}/genhash
%attr(0755,root,root) %{_sbindir}/keepalived
%{_mandir}/man1/genhash.1*
%{_mandir}/man5/keepalived.conf.5*
%{_mandir}/man8/keepalived.8*

%changelog
* Sat Jul 23 2016 josef radinger <cheese@nosuchhost.net> - 1.2.23-1
- bump version

* Fri Jun 17 2016 josef radinger <cheese@nosuchhost.net> - 1.2.22-1
- bump version

* Fri Jun 03 2016 josef radinger <cheese@nosuchhost.net> - 1.2.21-1
- bump version
- add BuildRequires on libnfnetlink

* Wed Aug 05 2015 josef radinger <cheese@nosuchhost.net> - 1.2.19-2
- fix systemd

* Wed Aug 05 2015 josef radinger <cheese@nosuchhost.net> - 1.2.19-1
- bump version

* Sun Jun 07 2015 josef radinger <cheese@nosuchhost.net> - 1.2.17-1
- bump version
- add MIBS

* Fri Jan 09 2015 josef radinger <cheese@nosuchhost.net> - 1.2.15-1
- bump version
- disable patch0

* Sat Nov 15 2014 josef radinger <cheese@nosuchhost.net> - 1.2.13-4.1
- bump version

* Wed Aug 07 2014 Ryan O'Hara <rohara@redhat.com> - 1.2.13-4
- Bump release number
  Related: rhbz#1100029, rhbz#1100030

* Thu May 22 2014 Ryan O'Hara <rohara@redhat.com> - 1.2.13-3
- Minor spec file modifications
  Resolves: rhbz#1100029, rhbz#1100030

* Wed May 21 2014 Ryan O'Hara <rohara@redhat.com> - 1.2.13-2
- Add SNMP subsystem option to man page
  Resolves: rhbz#1100028

* Wed May 21 2014 Ryan O'Hara <rohara@redhat.com> - 1.2.13-1
- Rebase to upstream version 1.2.13
  Resolves: rhbz#1052380, rhbz#1077201, rhbz#1007575, rhbz#967641

* Wed Sep 26 2012 Ryan O'Hara <rohara@redhat.com> - 1.2.7-3
- Don't strip binaries at build time.
  Resolves: rhbz#846064

* Fri Sep 21 2012 Ryan O'Hara <rohara@redhat.com> - 1.2.7-2
- Bump release number.
  Resolves: rhbz#846064

* Thu Sep 20 2012 Ryan O'Hara <rohara@redhat.com> - 1.2.7-1
- Initial build.
  Resolves: rhbz#846064
